@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 
 from time import sleep
-from portfolio import Portfolio
+from pyetf.finance.portfolio import Portfolio
 from datetime import datetime
 import argparse
 
@@ -18,8 +18,11 @@ parser = argparse.ArgumentParser(description='Aggiorna il portafoglio per tenere
 parser.add_argument('-f', '--file', type=str, required=False, default='Info.csv', help='Percorso per il file Info.csv del portafoglio')
 args = parser.parse_args()
 
-p = Portfolio(args.file)
-country = p.portfolioCountries()
+try:
+    p = Portfolio(args.file)
+    country = p.portfolioCountries()
+except IndexError:
+    raise IndexError('Percorso al file (Info.csv) errato !')
 print('Starting the program:')
 print('Country: ' + country)
 
@@ -28,12 +31,15 @@ while True:
     time = datetime.now()
     if doRefresh(time, country):
         if OK is False:
-            p = Portfolio(args.file)
-            print(f'Portfolio aggiornato ! --> {time.strftime("%A %d %B %Y - %H:%M")}')
-            print(p.data.tail(1))
-            print("----------------------------------------------------------------------------")
-            if country != 'Mix':
-                OK = True
+            try:
+                p = Portfolio(args.file)
+                print(f'Portfolio aggiornato ! --> {time.strftime("%A %d %B %Y - %H:%M")}')
+                print(p.data.tail(1))
+                print("----------------------------------------------------------------------------")
+                if country != 'Mix':
+                    OK = True
+            except ConnectionError:
+                print('Errore di Connessione ! Impossibile aggiornare il Portafoglio.')
     else:
         OK = False
     print(f'{time.strftime("%A %d %B %Y - %H:%M")} Sleeping...')
